#define _MCMCGLMM_H

extern "C"{
#include "cs.h"
}

#ifndef _GENERAL_H
#include "General.h"
#endif

#ifndef _CS_CBIND_H
extern "C"{
#include "cs_cbind.h"
}
#endif

#ifndef _CS_KRONECKERI_H
extern "C"{
#include "cs_kroneckerI.h"
}
#endif

#ifndef _CS_KRONECKERA_H
extern "C"{
#include "cs_kroneckerA.h"
}
#endif

#ifndef _CS_KRONECKERH_H
extern "C"{
#include "cs_kroneckerH.h"
}
#endif

#ifndef _CS_KRONECKERIMII_H
extern "C"{
#include "cs_kroneckerImii.h"
}
#endif

#ifndef _CS_OMEGA_H
extern "C"{
#include "cs_omega.h"
}
#endif

#ifndef _CS_DIRECTSUM_H
extern "C"{
#include "cs_directsum.h"
}
#endif

#ifndef _CS_RWISHART_H
extern "C"{
#include "cs_rwishart.h"
}
#endif

#ifndef _CS_RINVWISHART_H
extern "C"{
#include "cs_rinvwishart.h"
}
#endif

#ifndef _CS_RCINVWISHART_H
extern "C"{
#include "cs_rCinvwishart.h"
}
#endif

#ifndef _CS_RR_H
extern "C"{
#include "cs_rR.h"
}
#endif

#ifndef _CS_INV_H
extern "C"{
#include "cs_inv.h"
}
#endif

#ifndef _CS_DMVNORM_H
extern "C"{
#include "cs_dmvnorm.h"
}
#endif

#ifndef _CS_DCMVNORM_H
extern "C"{
#include "cs_dcmvnorm.h"
}
#endif

#ifndef _PCMVNORM_H
extern "C"{
#include "pcmvnorm.h"
}
#endif

#ifndef _CS_TMULTIPLYUPDATE_H
extern "C"{
#include "cs_tmultiplyupdate.h"
}
#endif

#ifndef _DCUTPOINTS_H
extern "C"{
#include "dcutpoints.h"
}
#endif

#ifndef _RTNORM_H
extern "C"{
#include "rtnorm.h"
}
#endif

#ifndef _RTCMVNORM_H
extern "C"{
#include "rtcmvnorm.h"
}
#endif

#ifndef _LPZF_H
extern "C"{
#include "lpzF.h"
}
#endif

#ifndef _CS_SORTDV_H
extern "C"{
#include "cs_sortdv.h"
}
#endif



